<div class=chatlog__embed>
    <div class=chatlog__embed-color-pill style=background-color:rgba({{EMBED_R}},{{EMBED_G}},{{EMBED_B}},1)></div>
    <div class=chatlog__embed-content-container>
        <div class=chatlog__embed-content>
            <div class=chatlog__embed-text>
                <div class="chatlog__embed-author">
                    <span class="chatlog__embed-author-name">{{EMBED_AUTHOR}}</span>
                </div>
                <div class="chatlog__embed-title">
                        <span class="markdown">{{EMBED_TITLE}}</span>
                </div>


                <div class=chatlog__embed-description>
                    <span class=markdown>{{EMBED_DESC}}</span>
                </div>
                <div class="chatlog__embed-fields">
                    {{EMBED_FIELDS}}
                </div>

            </div>
            <div class="chatlog__embed-thumbnail-container">
                <a class="chatlog__embed-thumbnail-link" href="{{EMBED_IMAGE}}">
                <img class="chatlog__embed-thumbnail" src="{{EMBED_IMAGE}}">
            </a>
            </div>
        </div>

        {{EMBED_FOOTER}}

    </div>
</div>

