            <div class="chatlog__message " data-message-id="{{MESSAGE_ID}}" id="message-{{MESSAGE_ID}}">
                <div class="chatlog__content">
                    <span class="markdown">{{MESSAGE_CONTENT}}</span>
                </div>

                <div class="chatlog__reactions">
                    {{EMOJI}}
                </div>

                {{EMBEDS}}

                {{ATTACHMENTS}}

            </div>